@@ -16,7 +16,6 @@ Helpers are provided for postgresql, mysql and sqlite.
 """
 __docformat__ = "restructuredtext en"
 
-from logilab.common.deprecation import obsolete
 
 class BadQuery(Exception): pass
 class UnsupportedFunction(BadQuery): pass
@@ -158,20 +157,6 @@ class _GenericAdvFuncHelper:
             raise UnsupportedFunction(funcname)
     function_description = classmethod(function_description)
 
-    #@obsolete('use users_support attribute')
-    def support_users(self):
-        """return True if the DBMS support users (this is usually
-        not true for in memory DBMS)
-        """
-        return self.users_support
-    support_user = obsolete('use users_support attribute')(support_users)
-
-    #@obsolete('use groups_support attribute')
-    def support_groups(self):
-        """return True if the DBMS support groups"""
-        return self.groups_support
-    support_user = obsolete('use groups_support attribute')(support_groups)
-
     def func_sqlname(self, funcname):
         funcdef = self.function_description(funcname)
         return funcdef.backend_name(self.backend_name)
@@ -433,6 +418,16 @@ class _SqliteAdvFuncHelper(_GenericAdvFuncHelper):
     intersect_all_support = False
     alter_column_support = False
 
+    def backup_command(self, dbname, dbhost, dbuser, backupfile,
+                       keepownership=True):
+        """return a command to backup the given database"""
+        return 'gzip --stdout %s > %s' % (dbname, backupfile)
+
+    def restore_commands(self, dbname, dbhost, dbuser, backupfile,
+                         encoding='utf-8', keepownership=True, drop=True):
+        """return a list of commands to restore a backup the given database"""
+        return ['gunzip --stdout %s > %s' % (backupfile, dbname)]
+
     def sql_create_index(self, table, column, unique=False):
         idx = self._index_name(table, column, unique)
         if unique:
